@@ -2,8 +2,6 @@ import click
 import os, sys
 import logging
 
-from nextcode.client import Client
-from nextcode.exceptions import InvalidProfile
 from .utils import console_handler, abort
 
 help_string = """A utility for interfacing with WuXi Nextcode services.
@@ -13,17 +11,17 @@ For all usage you will need to authenticate against the specific service profile
 
 Please look at the subcommands below for details.
 """
-
 plugin_folder = os.path.join(os.path.dirname(__file__), 'commands')
 profile_check = False
 
+
 class CLI(click.MultiCommand):
     def __init__(self, *args, **kwargs):
         click.MultiCommand.__init__(self, *args, **kwargs)
         opt = click.Option(
             param_decls=["--verbose", "-v"],
             help='Output logs for debugging',
-            type=click.Choice(['warning', 'error', 'info']),
+            type=click.Choice(['debug', 'warning', 'error', 'info']),
         )
         self.params.append(opt)
         opt = click.Option(
@@ -45,17 +43,6 @@ class CLI(click.MultiCommand):
         return rv
 
     def get_command(self, ctx, name):
-        # quick and dirty profile check
-        global profile_check
-        if not profile_check:
-            profile_check = True
-            try:
-                _ = Client()
-            except InvalidProfile:
-                cmd = sys.argv[1] if len(sys.argv) > 1 else None
-                if cmd not in ("profile", "version"):
-                    click.secho("You need to add a profile with: nextcode profile add <name>", fg="yellow")
-
         ns = {}
         fn = os.path.join(plugin_folder, name)
         # if the command is a folder we look for the entrypoint in the __init__ file
@@ -90,6 +77,14 @@ class Context(object):
 @click.pass_context
 def cli(ctx, verbose=None, profile=None):
     """Convert files using specified converter"""
+    # by default we log out to console WARN and higher but can view info with -v
+    # make sure this is called before importing the sdk so that we can grab all logging
+    if verbose:
+        console_handler.setLevel(getattr(logging, verbose.upper()))
+
+    from nextcode.client import Client
+    from nextcode.exceptions import InvalidProfile
+
     if ctx.obj is None:
         ctx.obj = Context()
         ctx.obj.verbose = verbose
@@ -99,10 +94,6 @@ def cli(ctx, verbose=None, profile=None):
         except InvalidProfile:
             pass
 
-    # by default we log out to console WARN and higher but can view info with -v
-    if verbose:
-        console_handler.setLevel(getattr(logging, verbose.upper()))
-
 
 if __name__ == '__main__':
     cli()  # pylint: disable=no-value-for-parameter
