@@ -78,7 +78,7 @@ def jobs(
             abort("You cannot combine --status with other filter flags")
 
     if is_mine:
-        data['user_name'] = session.current_user['preferred_username']
+        data['user_name'] = svc.current_user['preferred_username']
         data['status'] = 'ALL'
     elif user_name:
         data['user_name'] = user_name
