@@ -103,7 +103,13 @@ def edit(ctx):
 )
 @click.option('-k', '--api-key', help="API Key (if not set a browser will open)")
 @click.option('-r', '--replace', is_flag=True, default=False, help="Replace an existing profile")
-@click.option('-s', '--skip-auth', is_flag=True, default=False, help="Skip authenetication (for local development)")
+@click.option(
+    '-s',
+    '--skip-auth',
+    is_flag=True,
+    default=False,
+    help="Skip authenetication (for local development)",
+)
 @click.pass_context
 def add(ctx, profile, domain, api_key, replace, skip_auth):
     """Creates a new profile of the specified name and allows you to configure it"""
@@ -139,7 +145,9 @@ def add(ctx, profile, domain, api_key, replace, skip_auth):
 
             if reachable:
                 click.echo(
-                    "Launching login webpage {} ==> Please retrieve API Key from browser".format(url)
+                    "Launching login webpage {} ==> Please retrieve API Key from browser".format(
+                        url
+                    )
                 )
                 click.launch(url)
                 click.pause()
