@@ -33,7 +33,7 @@ def cli(ctx):
 
 
 from nextcodecli.commands.project.fileaccess import list_bucket, upload, download, delete, head
-from nextcodecli.commands.project.status import status, create, update
+from nextcodecli.commands.project.status import status, create, update, view
 from nextcodecli.commands.project.users import users
 
 cli.add_command(list_bucket)
@@ -45,3 +45,4 @@ cli.add_command(status)
 cli.add_command(users)
 cli.add_command(create)
 cli.add_command(update)
+cli.add_command(view)
