@@ -20,7 +20,12 @@ log = get_logger()
 @option('--pipeline', 'pipeline', default=None, help='Filter by pipeline name')
 @option('--page', 'is_page', is_flag=True, help='Page results')
 @option('--running', 'is_running', is_flag=True, help='Only show jobs in pending/running state')
-@option('--completed', 'is_completed', is_flag=True, help='Only show jobs in failed/cancelled/completed state')
+@option(
+    '--completed',
+    'is_completed',
+    is_flag=True,
+    help='Only show jobs in failed/cancelled/completed state',
+)
 @option('-n', '--num', default=20, help='Maximum number of jobs to return')
 @option(
     '-o',
@@ -31,7 +36,20 @@ log = get_logger()
 )
 @option('--raw', 'is_raw', is_flag=True, help='Dump raw json for further processing')
 @pass_context
-def jobs(ctx, is_mine, user_name, status, project, pipeline, is_page, is_running, is_completed, num, output, is_raw):
+def jobs(
+    ctx,
+    is_mine,
+    user_name,
+    status,
+    project,
+    pipeline,
+    is_page,
+    is_running,
+    is_completed,
+    num,
+    output,
+    is_raw,
+):
     svc = ctx.obj.service
     if is_mine:
         try:
@@ -45,7 +63,9 @@ def jobs(ctx, is_mine, user_name, status, project, pipeline, is_page, is_running
     elif is_completed:
         state = "completed"
     try:
-        jobs = svc.get_jobs(user_name, status, project=project, pipeline=pipeline, limit=num, state=state)
+        jobs = svc.get_jobs(
+            user_name, status, project=project, pipeline=pipeline, limit=num, state=state
+        )
     except ServerError as e:
         abort(str(e))
     is_wide = output == 'wide'
@@ -84,7 +104,9 @@ def jobs(ctx, is_mine, user_name, status, project, pipeline, is_page, is_running
             elif f == '#proc':
                 v = sum(job.details.get('process_stats', {}).values())
             elif f == 'desc':
-                v = job.description
+                v = job.description or ""
+                if len(v) > 50:
+                    v = v[:47] + "..."
             job_list.append(v)
 
         jobs_list.append(job_list)
