@@ -15,10 +15,7 @@ from nextcodecli.utils import dumps, print_tab
 @option('-m', '--manifest', 'is_manifest', is_flag=True, help='Output a manifest for this pipeline')
 @pass_context
 def pipelines(ctx, pipeline_name, is_raw, is_details, is_manifest):
-    session = ctx.obj.session
-    data = {}
-    resp = session.get(session.url_from_endpoint('pipelines'), json=data)
-    pipelines = resp.json()['pipelines']
+    pipelines = ctx.obj.service.get_pipelines()
 
     _pipeline_names = set()
     if pipeline_name:
