@@ -12,10 +12,7 @@ from nextcodecli.utils import dumps
 @option('--raw', 'is_raw', is_flag=True, help='Dump raw json for further processing')
 @pass_context
 def projects(ctx, is_raw):
-    session = ctx.obj.session
-    data = {}
-    resp = session.get(session.url_from_endpoint('projects'), json=data)
-    projects = resp.json()['projects']
+    projects = ctx.obj.service.get_projects()
     if is_raw:
         click.echo(dumps(projects))
         return
