@@ -8,7 +8,7 @@ import logging
 import subprocess
 
 from nextcode.packagelocal import package_and_upload
-from nextcode.exceptions import ServerError
+from nextcode.exceptions import ServerError, UploadError
 
 from nextcodecli.utils import abort
 
@@ -106,7 +106,10 @@ def run(
     build_context = pipeline_name
     if local_folder:
         path = os.path.abspath(os.path.expanduser(local_folder))
-        p = package_and_upload(ctx.obj.service, 'local_workflow', path)
+        try:
+            p = package_and_upload(ctx.obj.service, 'local_workflow', path)
+        except UploadError as ex:
+            abort(ex)
         build_source = 'url'
         build_context = p
     elif script:
