@@ -53,7 +53,7 @@ def get_results(qry, limit, filt, sort, output_file, is_json=False):
     echo("")
     if output_file:
         with open(os.path.expanduser(output_file), 'w') as f:
-            f.write(results + '\n')
+            f.write(results)
         echo("Results have been written to '%s'" % output_file)
 
     else:
